Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/dev/scsipi change scsipi_execute_xs() to default to simp...



details:   https://anonhg.NetBSD.org/src/rev/ea8e4c069e98
branches:  trunk
changeset: 818195:ea8e4c069e98
user:      jdolecek <jdolecek%NetBSD.org@localhost>
date:      Sun Oct 02 19:40:35 2016 +0000

description:
change scsipi_execute_xs() to default to simple tags for !XS_CTL_URGENT
if not specified by caller; this is mostly for documentation purposes
only, as sd(4) and cd(4) explicitly use simple tags already

diffstat:

 sys/dev/scsipi/scsipi_base.c |  8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diffs (35 lines):

diff -r 02a4f57b4744 -r ea8e4c069e98 sys/dev/scsipi/scsipi_base.c
--- a/sys/dev/scsipi/scsipi_base.c      Sun Oct 02 19:26:46 2016 +0000
+++ b/sys/dev/scsipi/scsipi_base.c      Sun Oct 02 19:40:35 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: scsipi_base.c,v 1.165 2015/08/24 23:13:15 pooka Exp $  */
+/*     $NetBSD: scsipi_base.c,v 1.166 2016/10/02 19:40:35 jdolecek Exp $       */
 
 /*-
  * Copyright (c) 1998, 1999, 2000, 2002, 2003, 2004 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: scsipi_base.c,v 1.165 2015/08/24 23:13:15 pooka Exp $");
+__KERNEL_RCSID(0, "$NetBSD: scsipi_base.c,v 1.166 2016/10/02 19:40:35 jdolecek Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_scsi.h"
@@ -1923,14 +1923,14 @@
        } else {
                /*
                 * If the request doesn't specify a tag, give Head
                 * tags to URGENT operations and Ordered tags to
                 * everything else.
                 */
                if (XS_CTL_TAGTYPE(xs) == 0) {
                        if (xs->xs_control & XS_CTL_URGENT)
                                xs->xs_control |= XS_CTL_HEAD_TAG;
                        else
-                               xs->xs_control |= XS_CTL_ORDERED_TAG;
+                               xs->xs_control |= XS_CTL_SIMPLE_TAG;
                }
 
                switch (XS_CTL_TAGTYPE(xs)) {
@@ -1923,14 +1923,14 @@
                /*
                 * If the request doesn't specify a tag, give Head
-                * tags to URGENT operations and Ordered tags to
+                * tags to URGENT operations and Simple tags to
                 * everything else.
                 */



Home | Main Index | Thread Index | Old Index